..
      Copyright 2012 Nicolas Barcet for Canonical

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

============================================
Welcome to the Aodh developer documentation!
============================================

What is the purpose of the project and vision for it?
=====================================================

* Provide alarms and notifications based on metrics.

This documentation offers information on how Aodh works and how to contribute
to the project.

Overview
========

.. toctree::
   :maxdepth: 2

   architecture
   webapi/index

Developer Documentation
=======================

.. toctree::
   :maxdepth: 2

   install/index
   configuration
   testing
   contributing

Appendix
========

.. toctree::
   :maxdepth: 1

   glossary
   api/index


.. update index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
